@@ -51,8 +51,8 @@ class Command(BaseCommand):
                 continue
             
             data.append([action, time])
-        print data 
-        print "last_Start: %s " % last_start
+        #print data 
+        #print "last_Start: %s " % last_start
         last_heating_period = None
         total_heating_period = 0
         for action, time in data:
@@ -76,17 +76,17 @@ class Command(BaseCommand):
         #si there is no data (for example: every line was out of time range, we need to know
         #the status of the flame. Therefore we use the last_start, which is set above, when the time range uis checked
         if len(data) == 0 and last_start is not None:
-            print "como todas las lineas son anteriores al periodo y esta arrancado desde antes, le meto el tiempo desde el principio del periodo"
+   #         print "como todas las lineas son anteriores al periodo y esta arrancado desde antes, le meto el tiempo desde el principio del periodo"
             total_heating_period = int(args[0]) * 60
-            print total_heating_period
+   #         print total_heating_period
         #if the first action in data is OFF, means the flame was on by the starting of the time range
         #it is needed to add this time
         if len(data) and data[0][0] == "OFF":
   #          print data[0][1]
-            print "como la pimera linea es OFF tenemos que add el tiempo desde el principip del periodo hasta el OFF, ates: %s" % total_heating_period
+    #        print "como la pimera linea es OFF tenemos que add el tiempo desde el principip del periodo hasta el OFF, ates: %s" % total_heating_period
              
             total_heating_period = int(total_heating_period) + int(data[0][1] - t_range[0])
-            print "despuest %s " % total_heating_period
+     #       print "despuest %s " % total_heating_period
         
         #if the last action is ON, need to add the time from the instance of that last action,
         #to the end of the range
@@ -94,7 +94,8 @@ class Command(BaseCommand):
             total_heating_period = int(total_heating_period) + int(t_range[1] - data[0][1])
         
         try:
-            print "total_heating_period:%d" % int(total_heating_period)
+            total_seconds = int(args[0]) * 60
+            print("absolute:%d percent:%.2f" % (total_heating_period, (100 * total_heating_period ) / total_seconds))
         except Exception, er:
             logging.error("Exception while trying to return the value: %s " % er)
             
